package com.nisum.application.dto;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;

@Data
@NoArgsConstructor
@AllArgsConstructor
public class ProfileDTO {

    private String profileId;

    @NotBlank(message = "First name is mandatory")
    @Pattern(regexp = "^[a-zA-Z ]*$", message = "First name should only contain letters and spaces")
    private String firstName;

    @NotBlank(message = "Last name is mandatory")
    @Pattern(regexp = "^[a-zA-Z ]*$", message = "Last name should only contain letters and spaces")
    private String lastName;

    @NotNull(message = "Date of birth is required.")
    @Pattern(regexp = "^\\d{2}-\\d{2}-\\d{4}$", message = "Date of birth must be in MM-DD-YYYY format")
    private String dob;

    @Pattern(regexp = "^[A-Z]{5}[0-9]{4}[A-Z]$", message = "PAN should follow the format AAAAA1111A")
    private String pan;

    @Pattern(regexp = "^[1-9][0-9]{11}$", message = "Aadhar must be a 12 digit number starting with 1-9")
    private String adhar;

    @NotBlank(message = "Mobile number is mandatory")
    @Pattern(regexp = "^[6-9][0-9]{9}$", message = "Mobile number should be 10 digits and start with 6/7/8/9")
    private String mobile;
}

